"use strict";

var _lodash = _interopRequireDefault(require("lodash"));
var _path = _interopRequireDefault(require("path"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const yargs = require('yargs');
const parse = (defaults, processArgv = process.argv) => {
  const argv = yargs()
  //        .exitProcess(false)
  .option('config', {
    alias: 'c',
    desc: 'The name of the configuration file',
    default: defaults.configFileName
  }).option('basePath', {
    alias: 'b',
    desc: 'The base-path URL prefix to each REST endpoints',
    type: 'string',
    default: defaults.webServer.basePath
  }).option('dumpConfig', {
    alias: 'd',
    desc: 'Print the effective configuration object to the console',
    type: 'boolean',
    default: false
  }).option('logLevel', {
    alias: 'l',
    desc: 'The log level',
    type: 'string',
    default: defaults.logger.level
  }).option('logFormat', {
    alias: 't',
    desc: 'The log (`plainText` or `json`)',
    type: 'string',
    default: defaults.logger.transports.console.format
  }).option('port', {
    alias: 'p',
    desc: 'The port the server will listen',
    type: 'string',
    default: defaults.webServer.port
  }).option('restApiPath', {
    alias: 'r',
    desc: 'The path to the REST API descriptors',
    type: 'string',
    default: defaults.webServer.restApiPath
  }).option('useCompression', {
    alias: 's',
    desc: 'Use middleware to compress response bodies for all request',
    type: 'boolean',
    default: defaults.webServer.useCompression
  })
  // MESSAGING related parameters
  .option('useMessaging', {
    alias: 'u',
    desc: 'Use messaging middleware to forward REST API calls',
    type: 'boolean',
    default: defaults.webServer.useMessaging
  }).option('topicPrefix', {
    desc: 'The topic prefix for messaging based forwarding of REST API calls',
    type: 'string',
    default: defaults.webServer.topicPrefix
  })
  // body parser config
  .option('parseRaw', {
    desc: 'Enable the raw body parser for the web server.',
    type: 'boolean',
    default: defaults.webServer.bodyParser.raw
  }).option('parseJson', {
    desc: 'Enable the JSON body parser for the web server.',
    type: 'boolean',
    default: defaults.webServer.bodyParser.json
  }).option('parseXml', {
    desc: 'Enable the XML body parser for the web server.',
    type: 'boolean',
    default: defaults.webServer.bodyParser.xml
  }).option('parseUrlencoded', {
    desc: 'Enable the URL Encoded body parser for the web server.',
    type: 'boolean',
    default: defaults.webServer.bodyParser.urlencoded
  }).option('natsUri', {
    alias: 'n',
    desc: 'NATS server URI used by the nats adapter.',
    type: 'string',
    default: defaults.nats.servers
  })
  // WebSocket related parameters
  .option('useWebsocket', {
    alias: 'w',
    desc: 'Use WebSocket server and message forwarding gateway',
    type: 'boolean',
    default: defaults.useWebsocket
  }).option('inbound', {
    alias: 'i',
    desc: 'Comma separated list of inbound NATS topics to forward through websocket',
    type: 'string',
    default: ''
  }).option('outbound', {
    alias: 'o',
    desc: 'Comma separated list of outbound NATS topics to forward towards from websocket',
    type: 'string',
    default: ''
  }).option('enableMocking', {
    alias: 'm',
    desc: 'Enable the server to use examples data defined in swagger files as mock responses.',
    type: 'boolean',
    default: defaults.webServer.enableMocking
  }).demandOption([]).showHelpOnFail(false, 'Specify --help for available options').help().parse(processArgv.slice(2));
  const results = {
    command: {
      name: 'server',
      args: {}
    },
    cliConfig: {
      configFileName: argv.config,
      useWebsocket: argv.useWebsocket,
      dumpConfig: argv.dumpConfig,
      logger: {
        level: argv.logLevel,
        transports: {
          console: {
            format: argv.logFormat
          }
        }
      },
      webServer: {
        port: argv.port,
        restApiPath: argv.restApiPath,
        basePath: argv.basePath,
        useMessaging: argv.useMessaging,
        topicPrefix: argv.topicPrefix,
        useCompression: argv.useCompression,
        staticContentBasePath: _path.default.resolve('./'),
        enableMocking: argv.enableMocking,
        bodyParser: {
          json: argv.parseJson,
          raw: argv.parseRaw,
          urlencoded: argv.parseUrlencoded,
          xml: argv.parseXml
        }
      },
      wsServer: {
        topics: {
          inbound: argv.inbound != '' ? _lodash.default.map(argv.inbound.split(','), t => t.trim()) : [],
          outbound: argv.outbound != '' ? _lodash.default.map(argv.outbound.split(','), t => t.trim()) : []
        }
      },
      nats: {
        servers: argv.natsUri
      }
    }
  };
  return results;
};
module.exports = {
  parse
};