"use strict";

var _path = _interopRequireDefault(require("path"));
var _lodash = _interopRequireDefault(require("lodash"));
var _chai = require("chai");
var _config = _interopRequireDefault(require("./config"));
var _npacNatsAdapter = _interopRequireDefault(require("npac-nats-adapter"));
var _npacWsgwAdapters = _interopRequireDefault(require("npac-wsgw-adapters"));
var _npacWebserverAdapter = _interopRequireDefault(require("npac-webserver-adapter"));
var _cli = _interopRequireDefault(require("./cli"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
before(done => {
  done();
});
after(done => {
  done();
});
describe('cli', () => {
  it('app without messaging', done => {
    const processArgv = ['node', 'src/index.js',
    // 'server',
    '-p', '3008', '-c', 'config.yml', '-r', '/tmp/restApi', '-s'];
    const defaults = _lodash.default.merge({}, _config.default, _npacWebserverAdapter.default.defaults, _npacNatsAdapter.default.defaults, _npacWsgwAdapters.default.defaults);
    const expected = {
      command: {
        name: 'server',
        args: {}
      },
      cliConfig: {
        configFileName: 'config.yml',
        useWebsocket: false,
        dumpConfig: false,
        logger: {
          level: 'info',
          transports: {
            console: {
              format: 'plainText'
            }
          }
        },
        webServer: {
          port: '3008',
          restApiPath: '/tmp/restApi',
          basePath: '/',
          staticContentBasePath: _path.default.resolve(),
          enableMocking: false,
          useMessaging: false,
          topicPrefix: 'easer',
          useCompression: true,
          bodyParser: {
            raw: true,
            json: false,
            xml: false,
            urlencoded: false
          }
        },
        wsServer: {
          topics: {
            inbound: [],
            outbound: []
          }
        },
        nats: {
          servers: ['nats://localhost:4222']
        }
      }
    };
    (0, _chai.expect)(_cli.default.parse(defaults, processArgv)).to.eql(expected);
    done();
  });
  it('app with messaging, default NATS server', done => {
    const processArgv = ['node', 'src/index.js',
    // 'server',
    '-p', '3008', '-c', 'config.yml', '-r', '/tmp/restApi', '-u'];
    const defaults = _lodash.default.merge({}, _config.default, _npacWebserverAdapter.default.defaults, _npacNatsAdapter.default.defaults, _npacWsgwAdapters.default.defaults);
    const expected = {
      command: {
        name: 'server',
        args: {}
      },
      cliConfig: {
        configFileName: 'config.yml',
        useWebsocket: false,
        dumpConfig: false,
        logger: {
          level: 'info',
          transports: {
            console: {
              format: 'plainText'
            }
          }
        },
        webServer: {
          port: '3008',
          restApiPath: '/tmp/restApi',
          basePath: '/',
          staticContentBasePath: _path.default.resolve(),
          enableMocking: false,
          useMessaging: true,
          topicPrefix: 'easer',
          useCompression: false,
          bodyParser: {
            raw: true,
            json: false,
            xml: false,
            urlencoded: false
          }
        },
        wsServer: {
          topics: {
            inbound: [],
            outbound: []
          }
        },
        nats: {
          servers: ['nats://localhost:4222']
        }
      }
    };
    (0, _chai.expect)(_cli.default.parse(defaults, processArgv)).to.eql(expected);
    done();
  });
  it('app with messaging, NATS server on localhost', done => {
    const processArgv = ['node', 'src/index.js',
    // 'server',
    '-p', '3008', '-c', 'config.yml', '-r', '/tmp/restApi', '-u', '-n', 'nats://localhost:4222'];
    const defaults = _lodash.default.merge({}, _config.default, _npacWebserverAdapter.default.defaults, _npacNatsAdapter.default.defaults, _npacWsgwAdapters.default.defaults);
    const expected = {
      command: {
        name: 'server',
        args: {}
      },
      cliConfig: {
        configFileName: 'config.yml',
        useWebsocket: false,
        dumpConfig: false,
        logger: {
          level: 'info',
          transports: {
            console: {
              format: 'plainText'
            }
          }
        },
        webServer: {
          port: '3008',
          restApiPath: '/tmp/restApi',
          basePath: '/',
          staticContentBasePath: _path.default.resolve(),
          enableMocking: false,
          useMessaging: true,
          topicPrefix: 'easer',
          useCompression: false,
          bodyParser: {
            raw: true,
            json: false,
            xml: false,
            urlencoded: false
          }
        },
        wsServer: {
          topics: {
            inbound: [],
            outbound: []
          }
        },
        nats: {
          servers: 'nats://localhost:4222'
        }
      }
    };
    (0, _chai.expect)(_cli.default.parse(defaults, processArgv)).to.eql(expected);
    done();
  });
  it('app with changed parsers', done => {
    const processArgv = ['node', 'src/index.js',
    // 'server',
    '-p', '3008', '-r', '/tmp/restApi', '--parseRaw', false, '--parseJson', true, '--parseXml', true, '--parseUrlencoded', true];
    const defaults = _lodash.default.merge({}, _config.default, _npacWebserverAdapter.default.defaults, _npacNatsAdapter.default.defaults, _npacWsgwAdapters.default.defaults);
    const expected = {
      command: {
        name: 'server',
        args: {}
      },
      cliConfig: {
        configFileName: 'config.yml',
        useWebsocket: false,
        dumpConfig: false,
        logger: {
          level: 'info',
          transports: {
            console: {
              format: 'plainText'
            }
          }
        },
        webServer: {
          port: '3008',
          restApiPath: '/tmp/restApi',
          basePath: '/',
          staticContentBasePath: _path.default.resolve(),
          enableMocking: false,
          useMessaging: false,
          topicPrefix: 'easer',
          useCompression: false,
          bodyParser: {
            raw: false,
            json: true,
            xml: true,
            urlencoded: true
          }
        },
        wsServer: {
          topics: {
            inbound: [],
            outbound: []
          }
        },
        nats: {
          servers: ['nats://localhost:4222']
        }
      }
    };
    (0, _chai.expect)(_cli.default.parse(defaults, processArgv)).to.eql(expected);
    done();
  });
});