"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startApp = void 0;
var _cli = _interopRequireDefault(require("./cli"));
var _npacNatsAdapter = _interopRequireDefault(require("npac-nats-adapter"));
var _npacWsgwAdapters = _interopRequireDefault(require("npac-wsgw-adapters"));
var _npacWebserverAdapter = _interopRequireDefault(require("npac-webserver-adapter/"));
var _npac = require("npac");
var _lodash = _interopRequireDefault(require("lodash"));
var _config = _interopRequireDefault(require("./config"));
var _defaultApi = require("./defaultApi");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const startApp = (argv = process.argv, cb = null) => {
  const defaults = _lodash.default.merge({}, _npacNatsAdapter.default.defaults, _npacWsgwAdapters.default.defaults, _npacWebserverAdapter.default.defaults, _config.default);

  // Use CLI to gain additional parameters, and command to execute
  const {
    cliConfig /*, command*/
  } = _cli.default.parse(defaults, argv);

  // Create the final configuration parameter set
  const config = (0, _npac.makeConfig)(defaults, cliConfig, 'configFileName');

  // Print the effective configuration on demand
  if (config.dumpConfig) {
    console.log('CONFIG: ', JSON.stringify(config, null, 2));
  }
  if (process.cwd() === config.webServer.restApiPath) {
    // The given restApiPath is the current working directory, so use the default-api instead
    config.webServer.restApiPath = _defaultApi.defaultApi;
  }

  // Define the adapters, executives and terminators to add to the container
  let appAdapters = [];
  let appTerminators = [];
  if (config.useWebsocket) {
    // Use websocket server and message forwarding gateway with MESSAGING
    appAdapters = [(0, _npac.mergeConfig)(config), _npac.addLogger, _npacNatsAdapter.default.startup, _npacWebserverAdapter.default.startup, _npacWsgwAdapters.default.startup];
    appTerminators = [_npacWsgwAdapters.default.shutdown, _npacWebserverAdapter.default.shutdown, _npacNatsAdapter.default.shutdown];
  } else {
    if (config.webServer.useMessaging) {
      // Use MESSAGING without websocket
      appAdapters = [(0, _npac.mergeConfig)(config), _npac.addLogger, _npacNatsAdapter.default.startup, _npacWebserverAdapter.default.startup];
      appTerminators = [_npacWebserverAdapter.default.shutdown, _npacNatsAdapter.default.shutdown];
    } else {
      // No Websocket no MESSAGING
      appAdapters = [(0, _npac.mergeConfig)(config), _npac.addLogger, _npacWebserverAdapter.default.startup];
      appTerminators = [_npacWebserverAdapter.default.shutdown];
    }
  }

  // Define the jobs to execute: hand over the command got by the CLI.
  const jobs = [];

  //Start the container
  (0, _npac.start)(appAdapters, jobs, appTerminators, cb);
};
exports.startApp = startApp;