"use strict";

var _path = _interopRequireDefault(require("path"));
var _sinon = _interopRequireDefault(require("sinon"));
var _npac = require("npac");
var _index = require("./index");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
describe('app', () => {
  let sandbox;
  before(done => {
    (0, _npac.removeSignalHandlers)();
    sandbox = _sinon.default.createSandbox({});
    done();
  });
  afterEach(done => {
    (0, _npac.removeSignalHandlers)();
    sandbox.restore();
    done();
  });
  it('#start - default mode', done => {
    (0, _npac.catchExitSignals)(sandbox, done);
    const processArgv = ['node', 'src/app.js', '-r', _path.default.resolve(), '-n', 'nats://localhost:4222'];
    (0, _index.startApp)(processArgv, (err, res) => {
      console.log('Send SIGTERM signal');
      process.kill(process.pid, 'SIGTERM');
    });
  });
  it('#start - with MESSAGING', done => {
    (0, _npac.catchExitSignals)(sandbox, done);
    const port = 8080;
    const processArgv = ['node', 'src/app.js', '-p', `${port}`, '-u', '-r', _path.default.resolve(), '-n', 'nats://localhost:4222'];
    (0, _index.startApp)(processArgv, (err, res) => {
      console.log('Send SIGTERM signal');
      process.kill(process.pid, 'SIGTERM');
    });
  });
  it('#start - with indirect args', done => {
    (0, _npac.catchExitSignals)(sandbox, done);
    const port = 8081;
    process.argv = ['node', 'src/app.js', '-p', `${port}`, '-r', _path.default.resolve(), '-n', 'nats://localhost:4222'];
    (0, _index.startApp)(port[42], (err, res) => {
      console.log('Send SIGTERM signal');
      process.kill(process.pid, 'SIGTERM');
    });
  });
});